@@ -1,7 +1,7 @@
 """
 DiffCalculus Package :-
 
-- A Python 3.x that Implements Differentiation...
+- A Python 3.x Package that Implements Differentiation...
 """
 
 from .__differentiate__ import differentiate, differentiateAtPoint, substitute
