@@ -1,5 +1,5 @@
 """
-Contains Classes of Differentiable Functions that creates Differentiable Functions Objects.
+Contains Classes of Differentiable Functions that creates Differentiable Function Objects.
 """
 
 from .errors import *
@@ -69,7 +69,10 @@ class complexFn:
 		if any(param):
 			u, v, result = param[0], param[1], ""
 
-			if bool(repr(u)) and (u != 0) and (u != 1):
+			# First Term Representation
+			if bool(repr(u)) and isinstance(u, complexFn):
+				result += f"({u})"
+			elif bool(repr(u)) and (u != 0) and (u != 1):
 				result += f"{u}"
 			elif u == 0:
 				if op == "-":
@@ -102,7 +105,10 @@ class complexFn:
 			# Second Term Representation
 			if v != 1:
 				if op == "/":
-					result += f"{v}"
+					if isinstance(v, complexFn):
+						result += f"({v})"
+					else:
+						result += f"{v}"
 				else:
 					result += f" {v}"
 			elif (v == 1) and (op in ("+", "-")):
